// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"net/http"
	"smart-site-management-gateway/errors"
	param_v1 "smart-site-management-gateway/param/v1"
	"smart-site-management-gateway/pb"
	"smart-site-management-gateway/pb/v1"
	"smart-site-management-gateway/utils"

	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
)

//
// @Summary 告警列表
// @Description 告警列表
// @Tags 告警前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param start query int64 false " "
// @Param end query int64 false " "
// @Param sn query string false " "
// @Param timestamp query int false " "
// @Param filter query int false "0 不过滤 1 已处理 2 未处理"
// @Param page_size query int false " "
// @Param device_code query int false "设备类型"
// @Success 200 {object} v1.AlarmListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/list [get]
func (c *Controller) AlarmList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.AlarmListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.AlarmListResponse{}
		rpcReq := &v1.AlarmListRequest{
			ProjectId: projectId,
			Page:      req.Page,
			Start:     req.Start,
			End:       req.End,
			Sn:        req.Sn,
			Filter:req.Filter,
			PageSize:req.PageSize,
			Timestamp:req.Timestamp,
			DeviceCode:req.DeviceCode,
		}

		rpcRsp, err := pb.Project.AlarmList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.AlarmList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.AlarmItem{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 告警规则添加
// @Description 告警规则添加
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.AlarmRuleAddBody true " "
// @Success 200 {object} v1.AlarmRuleAddResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/rule [post]
func (c *Controller) AlarmRuleAdd(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmRuleAddRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.AlarmRuleAddBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmRuleAddResponse{}
		rpcReq := &v1.AlarmRuleAddRequest{
			ProjectId:      projectId,
			Sn:             req.Sn,
			AlarmCount:     req.AlarmCount,
			SilencePeriod:  req.SilencePeriod,
			IsOn:           req.IsOn,
			ContinuePeriod: req.ContinuePeriod,
		}

		rpcRsp, err := pb.Project.AlarmRuleAdd(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmRuleAdd"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("告警规则添加", loginUid, userName, s, err, pid)
}

//
// @Summary 告警规则列表
// @Description 告警规则列表
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string false "设备唯一编号，不传获取所有的告警规则列表"
// @Param page query int false " "
// @Success 200 {object} v1.AlarmRuleListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/rule_list [get]
func (c *Controller) AlarmRuleList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmRuleListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.AlarmRuleListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.AlarmRuleListResponse{}
		rpcReq := &v1.AlarmRuleListRequest{
			ProjectId: projectId,
			Sn:        req.Sn,
			Page:req.Page,
		}

		rpcRsp, err := pb.Project.AlarmRuleList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmRuleList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.AlarmRule, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 删除告警规则
// @Description 删除告警规则
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id path int true "规则id"
// @Success 200 {object} v1.AlarmRuleDeleteResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/rule_delete/{id} [delete]
func (c *Controller) AlarmRuleDelete(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmRuleDeleteRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, &req.AlarmRuleDeletePath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmRuleDeleteResponse{}
		rpcReq := &v1.AlarmRuleDeleteRequest{
			Id: req.Id,
		}

		_, err = pb.Project.AlarmRuleDelete(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmRuleDelete"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("删除告警规则", loginUid, userName, s, err, pid)
}

//
// @Summary 告警规则起停用
// @Description 告警规则起停用
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.AlarmRuleOnOffBody true " "
// @Success 200 {object} v1.AlarmRuleOnOffResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/rule_on_off [put]
func (c *Controller) AlarmRuleOnOff(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmRuleOnOffRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.AlarmRuleOnOffBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmRuleOnOffResponse{}
		rpcReq := &v1.AlarmRuleOnOffRequest{
			Id:   req.Id,
			IsOn: req.Is0n,
		}

		_, err = pb.Project.AlarmRuleOnOff(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmRuleOnOff"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("告警规则启停用", loginUid, userName, s, err, pid)
}

//
// @Summary 告警规则更新
// @Description 告警规则更新
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.AlarmRuleUpdateBody true " "
// @Success 200 {object} v1.AlarmRuleUpdateResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/rule [put]
func (c *Controller) AlarmRuleUpdate(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmRuleUpdateRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.AlarmRuleUpdateBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmRuleUpdateResponse{}
		rpcReq := &v1.AlarmRuleUpdateRequest{}

		rpcReq.Rule = &v1.AlarmRule{
			ProjectId:      projectId,
			Sn:             req.Sn,
			AlarmCount:     req.AlarmCount,
			SilencePeriod:  req.SilencePeriod,
			IsOn:           req.IsOn,
			Id:             req.Id,
			ContinuePeriod: req.ContinuePeriod,
		}

		_, err = pb.Project.AlarmRuleUpdate(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmRuleUpdate"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("告警规则更新", loginUid, userName, s, err, pid)
}

//
// @Summary 添加告警联系人
// @Description 添加告警联系人
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.AlarmContactAddBody true " "
// @Success 200 {object} v1.AlarmContactAddResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/contact [post]
func (c *Controller) AlarmContactAdd(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmContactAddRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.AlarmContactAddBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmContactAddResponse{}
		rpcReq := &v1.AlarmContactAddRequest{
			ProjectId: projectId,
			Phone:     req.Phone,
			Email:     req.Email,
		}

		rpcResp, err := pb.Project.AlarmContactAdd(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmContactAdd"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		resp.Data = *rpcResp

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("添加告警联系人", loginUid, userName, s, err, pid)
}

//
// @Summary 告警联系人列表
// @Description 告警联系人列表
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.AlarmContactListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/contact_list [get]
func (c *Controller) AlarmContactList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmContactListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.AlarmContactListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.AlarmContactListResponse{}
		rpcReq := &v1.AlarmContactListRequest{
			ProjectId: projectId,
		}

		rpcResp, err := pb.Project.AlarmContactList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmContactList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		resp.Data = *rpcResp

		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.AlarmContact, 0)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 删除告警联系人
// @Description 删除告警联系人列表
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id path string true " "
// @Success 200 {object} v1.AlarmContactDeleteResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/contact_delete/{id} [delete]
func (c *Controller) AlarmContactDelete(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmContactDeleteRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, &req.AlarmContactDeletePath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmContactDeleteResponse{}
		rpcReq := &v1.AlarmContactDeleteRequest{
			ProjectId: projectId,
			Id:        req.Id,
		}

		_, err = pb.Project.AlarmContactDelete(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmContactDelete"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("删除告警联系人", loginUid, userName, s, err, pid)
}

//
// @Summary 更新告警联系人
// @Description 更新告警联系人列表
// @Tags 告警后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.AlarmContactUpdateBody true " "
// @Success 200 {object} v1.AlarmContactUpdateResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/alarm/contact [put]
func (c *Controller) AlarmContactUpdate(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AlarmContactUpdateRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.AlarmContactUpdateBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.AlarmContactUpdateResponse{}
		rpcReq := &v1.AlarmContactUpdateRequest{}
		rpcReq.Contact = &v1.AlarmContact{
			ProjectId: projectId,
			Id:        req.Id,
			Phone:     req.Phone,
			Email:     req.Email,
		}

		_, err = pb.Project.AlarmContactUpdate(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AlarmContactUpdate"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("更新告警联系人", loginUid, userName, s, err, pid)
}
