// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"net/http"
	"smart-site-management-gateway/errors"
	param_v1 "smart-site-management-gateway/param/v1"
	"smart-site-management-gateway/pb"
	"smart-site-management-gateway/pb/v1"
	"smart-site-management-gateway/utils"

	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
)

//
// @Summary 扬尘历史
// @Description 扬尘历史
// @Tags 扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param type query int true " "
// @Param time query int64 true " "
// @Param sn query string true " "
// @Success 200 {object} v1.DustMonitorHistoryResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/history [get]
func (c *Controller) DustMonitorHistory(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DustMonitorHistoryRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.DustMonitorHistoryQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.DustMonitorHistoryResponse{}
		rpcReq := &v1.DustMonitorHistoryRequest{
			Sn:    req.Sn,
			Type:  req.Type,
			Time:req.Time,
		}

		rpcRsp, err := pb.Project.DustMonitorHistory(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.DustMonitorHistory"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 扬尘最近数据
// @Description 扬尘最近数据
// @Tags  扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param type query int false " "
// @Param sn query string false " "
// @Success 200 {object} v1.LatestDustMonitorDataResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/last [get]
func (c *Controller) LatestDustMonitorData(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.LatestDustMonitorDataRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.LatestDustMonitorQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.LatestDustMonitorDataResponse{}
		rpcReq := &v1.LatestDustMonitorDataRequest{
			Sn:   req.Sn,
			Type: req.Type,
			ProjectId:projectId,
		}

		rpcRsp, err := pb.Project.LatestDustMonitorData(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.LatestDustMonitorData"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp.Data
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 扬尘设备列表
// @Description 扬尘历史
// @Tags 扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int true " "
// @Param page_size query int true " "
// @Success 200 {object} v1.DustListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/list [get]
func (c *Controller) DustList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DustListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.DustListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.DustListResponse{}
		rpcReq := &v1.DustListRequest{
			PageSize:req.PageSize,
			Page:req.Page,
			ProjectId:projectId,
		}

		rpcRsp, err := pb.Project.DustList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.DustList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.DustListItem{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


//
// @Summary 扬尘aqi
// @Description 扬尘aqi
// @Tags 扬尘监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string true " "
// @Success 200 {object} v1.DustAqiResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/dust/aqi [get]
func (c *Controller) DustAqi(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DustAqiRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.DustAqiQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.DustAqiResponse{}
		rpcReq := &v1.DustAqiRequest{
			Sn:req.Sn,
		}

		rpcRsp, err := pb.Project.DustAqi(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.DustAqi"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data.Aqi = int(rpcRsp.Aqi)
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}
