// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
	"net/http"
	"smart-site-management-gateway/consts"
	"smart-site-management-gateway/errors"
	param_v1 "smart-site-management-gateway/param/v1"
	"smart-site-management-gateway/pb"
	"smart-site-management-gateway/pb/v1"
	"smart-site-management-gateway/utils"
)

//
// @Summary 扬尘设备列表
// @Description 设备列表
// @Tags 设备后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param filter query string false " "
// @Param state query int32 true "-1 0 1 "
// @Param status query int false " 审核状态 -1 不过滤， 0 待审核 1 通过 2 未通过  "
// @Success 200 {object} v1.DeviceListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/dust_list [get]
func (c *Controller) DeviceDustList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceListRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.DeviceListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		if req.Page < 1 {
			req.Page = 1
		}
		resp := param_v1.DeviceListResponse{}
		rpcReq := &v1.DeviceListRequest{
			Page:   req.Page,
			Filter: req.Filter,
			PageSize:req.PageSize,
			State:req.State,
		}
		//req.FilterStatus = "1"
		rpcReq.State = -1
		rpcReq.ProjectId = projectId
		rpcReq.TypeCode = consts.DeviceTypeDust

		reply, err := pb.Project.DeviceList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.DeviceItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 实名制设备列表
// @Description 实名制设备列表
// @Tags 设备后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param filter query string false " "
// @Param state query int32 true "-1 0 1 "
// @Param status query int false " 审核状态 -1 不过滤， 0 待审核 1 通过 2 未通过  "
// @Success 200 {object} v1.DeviceListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/attendance_list [get]
func (c *Controller) DeviceAttendanceList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceListRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.DeviceListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		if req.Page < 1 {
			req.Page = 1
		}
		resp := param_v1.DeviceListResponse{}
		rpcReq := &v1.DeviceListRequest{
			Page:   req.Page,
			Filter: req.Filter,
			PageSize:req.PageSize,
			State:req.State,
		}
		//req.FilterStatus = "1"
		rpcReq.State = -1
		rpcReq.ProjectId = projectId
		rpcReq.TypeCode = consts.DeviceTypeAttendance

		reply, err := pb.Project.DeviceList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.DeviceItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 所有设备列表
// @Description 所有设备列表
// @Tags 设备后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param filter query string false " "
// @Param state query int32 true "-1 0 1 "
// @Param status query int false " 审核状态 -1 不过滤， 0 待审核 1 通过 2 未通过  "
// @Success 200 {object} v1.DeviceListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/list [get]
func (c *Controller) DeviceList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceListRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.DeviceListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		if req.Page < 1 {
			req.Page = 1
		}
		resp := param_v1.DeviceListResponse{}
		rpcReq := &v1.DeviceListRequest{
			Page:   req.Page,
			Filter: req.Filter,
			PageSize:req.PageSize,
			State:req.State,
		}
		//req.FilterStatus = "1"
		rpcReq.StatusFilters = append(rpcReq.StatusFilters, 1)
		rpcReq.ProjectId = projectId
		rpcReq.AllType = true

		reply, err := pb.Project.DeviceList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.DeviceItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 视频设备列表
// @Summary 视频设备列表
// @Description 视频设备列表
// @Tags device
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param filter query string false "过滤字段"
// @Param state query int32 true "-1 0 1 "
// @Param page query int false " "
// @Success 200 {object} v1.VedioListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/vedio_list [get]
func (c *Controller) DeviceVedioList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.VedioListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.VedioListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.VedioListResponse{}
		rpcReq := &v1.VedioListRequest{}
		rpcReq.Page = req.Page
		rpcReq.ProjectId = projectId
		rpcReq.Filter = req.Filter
		rpcReq.State = req.State
		/*
			if req.FilterStatus != "" {
				array := strings.Split(req.FilterStatus, ",")
				for _, v := range array {
					value, _ := strconv.Atoi(v)
					rpcReq.StatusFilters = append(rpcReq.StatusFilters, int32(value))
				}
			}*/
		reply, err := pb.Project.VedioList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "VedioList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.VedioItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


// 通道列表
// @Summary 通道列表
// @Description 通道列表
// @Tags device
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string false " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param channel_no query string false " "
// @Success 200 {object} v1.ChannelListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/vedio_channel_list [get]
func (c *Controller) DeviceVedioChannelList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ChannelListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.ChannelListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.ChannelListResponse{}
		rpcReq := &v1.ChannelListRequest{}
		rpcReq.Page = req.Page
		rpcReq.Sn = req.Sn
		rpcReq.ChannelNo = req.ChannelNo
		rpcReq.PageSise = req.PageSize
		rpcReq.ProjectId = projectId
		/*
			if req.FilterStatus != "" {
				array := strings.Split(req.FilterStatus, ",")
				for _, v := range array {
					value, _ := strconv.Atoi(v)
					rpcReq.StatusFilters = append(rpcReq.StatusFilters, int32(value))
				}
			}*/
		reply, err := pb.Project.ChannelList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ChannelList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ChannelItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 未绑定设备的通道列表
// @Summary 未绑定设备的通道列表
// @Description 未绑定设备的通道列表
// @Tags device
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.ChannelListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/vedio_channel_unbind [get]
func (c *Controller) DeviceVedioChannelUnbindList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ChannelListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.ChannelListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.ChannelListUnbindResponse{}
		rpcReq := &v1.ChannelListRequest{}
		rpcReq.ProjectId = projectId
		rpcReq.IsUnbind = true

		reply, err := pb.Project.ChannelList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ChannelList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data.List = reply.List
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ChannelItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

/*
// 申请的设备列表
// @Summary 申请的设备列表
// @Description 申请的设备列表
// @Tags 设备后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param filter query string false " "
// @Success 200 {object} v1.DeviceListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/apply_list [get]
func (c *Controller) DeviceApplyList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceListRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.DeviceListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		if req.Page < 1 {
			req.Page = 1
		}
		resp := param_v1.DeviceListResponse{}
		rpcReq := &v1.DeviceListRequest{
			Page:   req.Page,
			Filter: req.Filter,
		}

		rpcReq.StatusFilters = append(rpcReq.StatusFilters, 0)
		rpcReq.StatusFilters = append(rpcReq.StatusFilters, 2)

		rpcReq.ProjectId = projectId

		reply, err := pb.Project.DeviceList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.DeviceItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}
*/

// 设备入库审批
// @Summary 设备入库审批
// @Description 设备入库审批
// @Tags 设备后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.DeviceApproveBody true " "
// @Success 200 {object} v1.DeviceApproveResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/device_approve [put]
func (c *Controller) DeviceApprove(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceApproveRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.DeviceApproveBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.DeviceApproveResponse{}
		rpcReq := &v1.DeviceApproveRequest{
			Id:       req.Id,
			Status:   req.Status,
			Feedback: req.Feedback,
			DeviceCode:req.DeviceCode,
		}
		_, err = pb.Project.DeviceApprove(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceApprove"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("设备入库审批", loginUid, userName, s, err, pid)
}


// 项目信息
// @Summary 项目信息
// @Description 项目信息
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.ProjectInfoResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/info [get]
func (c *Controller) ProjectInfo(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectInfoRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}

		resp := param_v1.ProjectInfoResponse{}
		rpcReq := &v1.ProjectInfoRequest{
			ProjectId:projectId,
		}

		reply, err := pb.Project.ProjectInfo(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectInfo"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 项目设备统计
// @Summary 项目设备统计
// @Description 项目设备统计
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.ProjectDeviceStatisticsResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/device_statistics [get]
func (c *Controller) ProjectDeviceStatistics(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectDeviceStatisticsRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}

		resp := param_v1.ProjectDeviceStatisticsResponse{}
		rpcReq := &v1.ProjectDeviceStatisticsRequest{
			ProjectId:projectId,
		}

		reply, err := pb.Project.ProjectDeviceStatistics(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectDeviceStatistics"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = []*v1.ProjectDeviceStatistics{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 项目进度列表
// @Summary 项目进度列表
// @Description 项目进度列表
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.ProjectProgressResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/progress_list [get]
func (c *Controller) ProjectProgress(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectProgressRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}

		resp := param_v1.ProjectProgressResponse{}
		rpcReq := &v1.ProjectProgressRequest{
			ProjectId:projectId,
		}

		reply, err := pb.Project.ProjectProgress(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectProgress"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = []*v1.ProjectProgress{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 添加项目进度
// @Summary 添加项目进度
// @Description 添加项目进度
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectProgressAddBody true " "
// @Success 200 {object} v1.ProjectProgressAddResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/progress [post]
func (c *Controller) ProjectProgressAdd(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectProgressAddRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectProgressAddBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectProgressAddResponse{}
		rpcReq := &v1.ProjectProgressAddRequest{
			ProjectId:projectId,
			Name:req.Name,
			ExpectEndTime:req.ExpectEndTime,
			ExpectStartTime:req.ExpectStartTime,
		}

		reply, err := pb.Project.ProjectProgressAdd(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectProgressAdd"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("添加项目进度", loginUid, userName, s, err, pid)
}

//
// @Summary 项目进度完成或开工
// @Description 项目进度完成或开工
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectProgressSetBody true " "
// @Success 200 {object} v1.ProjectProgressSetResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/progress [put]
func (c *Controller) ProjectProgressSet(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectProgressSetRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectProgressSetBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		if (req.RealityStartTime <= 0 && req.RealityEndTime <= 0) ||
			(req.RealityStartTime > 0 && req.RealityEndTime > 0) {
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.ProjectProgressSetResponse{}
		rpcReq := &v1.ProjectProgressSetRequest{
			Id:req.Id,
			Image:req.Image,
			Start:req.RealityStartTime,
			End:req.RealityEndTime,
		}

		_, err = pb.Project.ProjectProgressSet(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectProgressSet"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("项目进度完成", loginUid, userName, s, err, pid)
}

// 删除项目进度
// @Summary 删除项目进度
// @Description 删除项目进度
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id path int64 true " "
// @Success 200 {object} v1.ProjectProgressDelResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/progress/{id} [delete]
func (c *Controller) ProjectProgressDel(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectProgressDelRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, &req.ProjectProgressDelPath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		// 响应数据
		resp := param_v1.ProjectProgressDelResponse{}
		rpcReq := &v1.ProjectProgressDelRequest{
			Id:req.Id,
		}

		_, err = pb.Project.ProjectProgressDel(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectProgressDel"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("删除项目进度", loginUid, userName, s, err, pid)
}

// 设备绑定的摄像头
// @Summary 设备绑定的摄像头
// @Description 设备绑定的摄像头
// @Tags device
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string false " "
// @Success 200 {object} v1.DeviceVideoChannelResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/device/vedio_channel [get]
func (c *Controller) DeviceVideoChannel(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.DeviceVideoChannelRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.DeviceVideoChannelQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.DeviceVideoChannelResponse{}
		rpcReq := &v1.DeviceVideoChannelRequest{}

		rpcReq.Sn = req.Sn
		rpcReq.ProjectId = projectId
		/*
			if req.FilterStatus != "" {
				array := strings.Split(req.FilterStatus, ",")
				for _, v := range array {
					value, _ := strconv.Atoi(v)
					rpcReq.StatusFilters = append(rpcReq.StatusFilters, int32(value))
				}
			}*/
		reply, err := pb.Project.DeviceVideoChannel(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "DeviceVideoChannel"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

// 设置项目平面图或效果图
// @Summary 设置项目平面图或效果图
// @Description 设置项目平面图或效果图
// @Tags 项目后台设置
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.ProjectSetPicBody true " "
// @Success 200 {object} v1.ProjectSetPicResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/pic [put]
func (c *Controller) ProjectSetPic(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectSetPicRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectSetPicBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		resp := param_v1.ProjectSetPicResponse{}
		rpcReq := &v1.ProjectSetPicRequest{
			ProjectId: projectId,
			PicUrl:req.PicUrl,
			PicType:req.PicType,
		}
		_, err = pb.Project.ProjectSetPic(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectSetPic"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}

		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("设置项目平面图或效果图", loginUid, userName, s, err, pid)
}

//
// @Summary 行政区域编码列表
// @Description 行政区域编码列表
// @Tags 行政区域
// @Accept  json
// @Produce  json
// @Success 200 {object} v1.AreaCodeListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/area_code_list [get]
func (c *Controller) AreaCodeList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.AreaCodeListRequest{}
	parseParamTask := func() error {
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据

		resp := param_v1.AreaCodeListResponse{}
		rpcReq := &v1.AreaCodeListRequest{}

		reply, err := pb.Project.AreaCodeList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "AreaCodeList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.AreaCodeItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


//
// @Summary 添加参建单位
// @Description 添加参建单位
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectCorpAddBody true " "
// @Success 200 {object} v1.ProjectCorpAddResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/corp [post]
func (c *Controller) ProjectCorpAdd(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectCorpAddRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectCorpAddBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectCorpAddResponse{}
		rpcReq := &v1.ProjectCorpAddRequest{
			ProjectId:projectId,
			Name:req.Name,
			AreaCode:req.AreaCode,
			SocialCode:req.SocialCode,
			RegisterDate:req.RegisterDate,
			CorpType:req.CorpType,
		}

		reply, err := pb.Project.ProjectCorpAdd(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectCorpAdd"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("添加参建单位", loginUid, userName, s, err, pid)
}


//
// @Summary 更新参建单位
// @Description 更新参建单位
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectCorpUpdateBody true " "
// @Success 200 {object} v1.ProjectCorpUpdateResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/corp [put]
func (c *Controller) ProjectCorpUpdate(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectCorpUpdateRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectCorpUpdateBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectCorpUpdateResponse{}
		rpcReq := &v1.ProjectCorpUpdateRequest{
			ProjectId:projectId,
			Id:req.Id,
			Name:req.Name,
			AreaCode:req.AreaCode,
			SocialCode:req.SocialCode,
			RegisterDate:req.RegisterDate,
			CorpType:req.CorpType,
		}

		_, err = pb.Project.ProjectCorpUpdate(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectCorpUpdate"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("更新参建单位", loginUid, userName, s, err, pid)
}

//
// @Summary 删除参建单位
// @Description 删除参建单位
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id  path int64 true " "
// @Success 200 {object} v1.ProjectCorpDelResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/corp/{id} [delete]
func (c *Controller) ProjectCorpDel(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectCorpDelRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, &req.ProjectCorpDelPath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectCorpDelResponse{}
		rpcReq := &v1.ProjectCorpDelRequest{
			ProjectId:projectId,
			Id:req.Id,
		}

		_, err = pb.Project.ProjectCorpDel(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectCorpDel"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("删除参建单位", loginUid, userName, s, err, pid)
}


//
// @Summary 参建单位列表
// @Description 参建单位列表
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.ProjectCorpListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/corp_list [get]
func (c *Controller) ProjectCorpList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectCorpListRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	//var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
	//	pid = projectId

		resp := param_v1.ProjectCorpListResponse{}
		rpcReq := &v1.ProjectCorpListRequest{
			ProjectId:projectId,
		}

		reply, err := pb.Project.ProjectCorpList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectCorpList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ProjectCorpListItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)

}







//
// @Summary 添加管理人员
// @Description 添加管理人员
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectPMAddBody true " "
// @Success 200 {object} v1.ProjectPMAddResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/pm [post]
func (c *Controller) ProjectPMAdd(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectPMAddRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectPMAddBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectPMAddResponse{}
		rpcReq := &v1.ProjectPMAddRequest{
			ProjectId:projectId,
			Name:req.Name,
			CorpId:req.CorpId,
			Phone:req.Phone,
			CertType:req.CertType,
			CertNum:req.CertNum,
			PType:req.PType,
		}

		reply, err := pb.Project.ProjectPMAdd(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectPMAdd"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("添加管理人员", loginUid, userName, s, err, pid)
}


//
// @Summary 更新管理人员
// @Description 更新管理人员
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body  body v1.ProjectPMUpdateBody true " "
// @Success 200 {object} v1.ProjectPMUpdateResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/pm [put]
func (c *Controller) ProjectPMUpdate(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectPMUpdateRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, nil, &req.ProjectPMUpdateBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectPMUpdateResponse{}
		rpcReq := &v1.ProjectPMUpdateRequest{
			ProjectId:projectId,
			Id:req.Id,
			Name:req.Name,
			CorpId:req.CorpId,
			Phone:req.Phone,
			CertType:req.CertType,
			CertNum:req.CertNum,
			PType:req.PType,
		}

		_, err = pb.Project.ProjectPMUpdate(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectPMUpdate"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("更新管理人员", loginUid, userName, s, err, pid)
}

//
// @Summary 删除管理人员
// @Description 删除管理人员
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id  path int64 true " "
// @Success 200 {object} v1.ProjectPMDelResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/pm/{id} [delete]
func (c *Controller) ProjectPMDel(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectPMDelRequest{}
	var loginUid int64
	var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, &req.ProjectPMDelPath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId

		resp := param_v1.ProjectPMDelResponse{}
		rpcReq := &v1.ProjectPMDelRequest{
			ProjectId:projectId,
			Id:req.Id,
		}

		_, err = pb.Project.ProjectPMDel(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectPMDel"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("删除管理人员", loginUid, userName, s, err, pid)
}


//
// @Summary 管理人员列表
// @Description 管理人员列表
// @Tags project
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Success 200 {object} v1.ProjectPMListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/project/pm_list [get]
func (c *Controller) ProjectPMList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.ProjectPMListRequest{}
	//var loginUid int64
	//var userName string

	parseParamTask := func() error {
		err := util.ShouldBind(ctx, &req.Header, nil, &req.ProjectPMListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	//var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
	//	pid = projectId

		resp := param_v1.ProjectPMListResponse{}
		rpcReq := &v1.ProjectPMListRequest{
			ProjectId:projectId,
			Page:req.Page,
			PageSize:req.PageSize,
			CorpId:req.CorpId,
			Filter:req.Filter,
		}

		reply, err := pb.Project.ProjectPMList(ctx, rpcReq)
		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "ProjectPMList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *reply
		if resp.Data.List == nil {
			resp.Data.List = make([]*v1.ProjectPMListItem, 0)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)

}
