package v1

import (
	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
	"net/http"
	"smart-site-management-gateway/errors"
	param_v1 "smart-site-management-gateway/param/v1"
	"smart-site-management-gateway/pb"
	"smart-site-management-gateway/pb/v1"
	"smart-site-management-gateway/utils"
)

//
// @Summary 任务列表
// @Description 任务列表
// @Tags 任务模块
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param start_time query int64 false " "
// @Param end_time query int64 false " "
// @Param filter query string false " 任务名，任务号 "
// @Param page_size query int false " "
// @Param task_type query int false " "
// @Param status query int false " "
// @Param overdue query int false " 0 不过滤 1 超期 2 未超期"
// @Param source query int false " 0 不过滤 1 普通 2 告警任务"
// @Success 200 {object} v1.TaskListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/task/list [get]
func (c *Controller) TaskList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.TaskListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.TaskListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.TaskListResponse{}
		rpcReq := &v1.TaskListRequest{
			Page:      req.Page,
			Start:     req.Start,
			End:       req.End,
			PageSize:req.PageSize,
			Filter:req.Filter,
			ProjectId:projectId,
			Source:req.Source,
			TaskType:req.TaskType,
			Overdue:req.Overdue,
		}
		if req.TaskType == 0 {
			rpcReq.TaskType = req.Type
		}
		if req.Status > 0 {
			rpcReq.Status =  make([]int32, 1)
			rpcReq.Status[0] = req.Status
		}

		rpcRsp, err := pb.Project.TaskList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.TaskList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.TaskListItem{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)

}

//
// @Summary 任务详情
// @Description 任务详情
// @Tags 任务模块
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param id path int true " "
// @Success 200 {object} v1.TaskInfoResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/task/info/{id} [get]
func (c *Controller) TaskInfo(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.TaskInfoRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, &req.TaskInfoPath, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.TaskInfoResponse{}
		rpcReq := &v1.TaskInfoRequest{
			Id:req.Id,
		}

		rpcRsp, err := pb.Project.TaskInfo(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Government.TaskInfo"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.TaskPipeline{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)

}



//
// @Summary 处理任务
// @Description 处理任务
// @Tags 任务模块
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param body body v1.TaskFinishBody true " "
// @Success 200 {object} v1.TaskFinishResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/task [put]
func (c *Controller) TaskFinish(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.TaskFinishRequest{}
	var loginUid int64
	var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, &req.TaskFinishBody)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
		loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	var pid int64
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		pid = projectId
		resp := param_v1.TaskFinishResponse{}
		rpcReq := &v1.TaskFinishRequest{
			Id:req.Id,
			ProjectId:projectId,
			ProcessingResults:req.ProcessingResults,
			ProcessingResultsImg:req.ProcessingResultsImg,
			ProcessingPerson:req.ProcessingPerson,
		}
		_, err = pb.Project.TaskFinish(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.TaskFinish"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	// 执行任务
	err := httptasker.Exec(ctx, parseParamTask, handleServiceTask)
	s, _ := json.MarshalToString(req)
	utils.LogWrite("处理任务", loginUid, userName, s, err, pid)

}
