// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"net/http"
	"smart-site-management-gateway/errors"
	param_v1 "smart-site-management-gateway/param/v1"
	"smart-site-management-gateway/parser"
	"smart-site-management-gateway/pb"
	"smart-site-management-gateway/pb/v1"
	"smart-site-management-gateway/utils"

	"github.com/gin-gonic/gin"
	"github.com/jaryhe/gopkgs/logger"
	"github.com/jaryhe/gopkgs/tasker/httptasker"
	"github.com/jaryhe/gopkgs/util"
	"go.uber.org/zap"
)

//
// @Summary 塔机历史
// @Description 塔机历史
// @Tags 塔吊监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param start query int64 false " "
// @Param end query int64 false " "
// @Param sn query string true " "
// @Success 200 {object} v1.TowerMonitorHistoryResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/iot/tower_history [get]
func (c *Controller) TowerMonitorHistory(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.TowerMonitorHistoryRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.TowerMonitorHistoryQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		resp := param_v1.TowerMonitorHistoryResponse{}
		rpcReq := &v1.TowerMonitorHistoryRequest{
			Sn:    req.Sn,
			Start:req.Start,
			End:req.End,
			PageSize:req.PageSize,
			Page:req.Page,
		}

		rpcRsp, err := pb.Project.TowerMonitorHistory(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.TowerMonitorHistory"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary 塔吊最近数据
// @Description 塔吊最近数据
// @Tags  塔吊监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string false " "
// @Success 200 {object} v1.LatestTowerMonitorDataResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/iot/tower_last [get]
func (c *Controller) LatestTowerMonitorData(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.LatestTowerMonitorDataRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.LatestTowerMonitorQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.LatestTowerMonitorDataResponse{}
		rpcReq := &v1.LatestTowerMonitorDataRequest{
			Sn:   req.Sn,
			ProjectId:projectId,
		}

		rpcRsp, err := pb.Project.LatestTowerMonitorData(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.LatestTowerMonitorData"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp.Data
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary iot设备列表
// @Description iot设备列表
// @Tags 塔吊监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param page query int false " "
// @Param page_size query int false " "
// @Param device_code query int true " "
// @Success 200 {object} v1.IotListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/iot/list [get]
func (c *Controller) IotList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.IotListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.IotListQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.IotListResponse{}
		rpcReq := &v1.IotListRequest{
			PageSize:req.PageSize,
			Page:req.Page,
			ProjectId:projectId,
			DeviceCode:req.DeviceCode,
		}

		rpcRsp, err := pb.Project.IotList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.IotList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.IotListItem{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}

//
// @Summary iot设备类型列表
// @Description iot设备类型列表
// @Tags 塔吊监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Success 200 {object} v1.IotTypeListResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/iot/type_list [get]
func (c *Controller) IotTypeList(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.IotTypeListRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, nil, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		// 响应数据
		resp := param_v1.IotTypeListResponse{}
		rpcReq := &v1.IotTypeListRequest{
			ProjectId:projectId,
		}

		rpcRsp, err := pb.Project.IotTypeList(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.IotList"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		if resp.Data.List == nil {
			resp.Data.List = []*v1.IotTypeListItem{}
		}
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}


//
// @Summary iot最近数据
// @Description iot最近数据
// @Tags  塔吊监控前台展示
// @Accept  json
// @Produce  json
// @Param token header string true " "
// @Param sn query string true " "
// @Param device_code query int true " "
// @Success 200 {object} v1.IotLastResponse
// @Failure 500 {object} base.HTTPError
// @Router /api/v1/iot/last [get]
func (c *Controller) IotLast(ctx *gin.Context) {
	// 解析参数
	req := &param_v1.IotLastRequest{}
	//var loginUid int64
	//var userName string
	parseParamTask := func() error {
		err := util.ShouldBind(ctx, nil, nil, &req.IotLastQuery, nil)
		if err != nil {
			logger.Error("func",
				zap.String("call", "util.ShouldBind"),
				zap.String("error", err.Error()))
			return errors.ParamsError
		}
	//	loginUid, userName, err = utils.GetJwtIdFromCtx(ctx)
		return nil
	}

	// 业务处理
	handleServiceTask := func() error {
		// 响应数据
		_, projectId, err := utils.GetSubjectValue(ctx)
		if err != nil {
			return err
		}
		resp := param_v1.IotLastResponse{}
		rpcReq := &v1.IotLastRequest{
			Sn:   req.Sn,
			ProjectId:projectId,
			DeviceCode:req.DeviceCode,
		}

		rpcRsp, err := pb.Project.IotLast(ctx, rpcReq)

		if err != nil {
			s, _ := json.MarshalToString(req)
			logger.Error("func",
				zap.String("call", "pb.Project.IotLast"),
				zap.String("params", s),
				zap.String("error", err.Error()))

			return errors.ErrorTransForm(err)
		}
		resp.Data = *rpcRsp
		resp.Data.Pic = parser.Conf.TowerPicUrl
		ctx.JSON(http.StatusOK, resp)
		return nil
	}

	// 执行任务
	httptasker.Exec(ctx, parseParamTask, handleServiceTask)
}
